var init = function () {
    var list = $('#list'),
        template = $('#template'),
        items = {};

    document.addEventListener('tizenhwkey', function (e) {
        if (e.keyName === 'back') {
            tizen.application.getCurrentApplication().exit();
        }
    });

    var listeners = {
        onprogress: function (id, receivedSize, totalSize) {
            var item = items[id];
            if (item) {
                var percentage = Math.round(receivedSize / totalSize * 100) + '%';
                item.bar.css({ width: percentage });
                item.percentage.text(percentage);
            }
        },
        oncompleted: function (id) {
            remove(id);
        }
    };

    var inputs = {
        url: $('#url'),
        download: $('#download')
    };

    list.on('click', '.icon-play', function () {
        var id = $(this).parents('li:first').attr('id'),
            item = items[id];

        if (item && tizen.download.getState(id) === 'PAUSED') {
            tizen.download.resume(id);
            item.play.hide();
            item.pause.show();
        }
    });

    list.on('click', '.icon-pause', function () {
        var id = $(this).parents('li:first').attr('id'),
            item = items[id];

        if (item && tizen.download.getState(id) === 'DOWNLOADING') {
            tizen.download.pause(id);
            item.pause.hide();
            item.play.show();
        }
    });

    list.on('click', '.icon-cancel', function () {
        var id = $(this).parents('li:first').attr('id'),
            item = items[id];

        if (item) {
            if (tizen.download.getState(id) !== 'COMPLETED') {
                tizen.download.cancel(id);
            }

            remove(id);
        }
    });

    var remove = function (id) {
        var item = items[id];
        item.li.fadeOut('slow', function () {
            item.li.remove();
            delete items[id];
        });
    };

    inputs.download.on('click', function () {
        var url = inputs.url.val(),
            fileName = url.split('/').pop();

        if (url) {
            // inputs.url.val('');

            var li = $(template.html()),
                name = li.find('.name'),
                bar = li.find('.bar'),
                percentage = li.find('.percentage'),
                play = li.find('.icon-play'),
                pause = li.find('.icon-pause'),
                cancel = li.find('.icon-cancel');

            var downloadRequest = new tizen.DownloadRequest(url, 'downloads'),
                id = tizen.download.start(downloadRequest, listeners);

            name.html(fileName);
            li.attr('id', id);
            list.append(li);

            items[id] = {
                li: li,
                name: name,
                bar: bar,
                percentage: percentage,
                play: play,
                pause: pause,
                cancel: cancel
            };
        }
    });
};

window.onload = init;